@@ -89,6 +89,9 @@ FAILEDOPERATION_KUBERNETESGETOPERATIONERROR = 'FailedOperation.KubernetesGetOper
 # Unknown Kubernetes error.
 FAILEDOPERATION_KUBERNETESINTERNAL = 'FailedOperation.KubernetesInternal'
 
+# Failed to obtain the kubernetes resource list.
+FAILEDOPERATION_KUBERNETESLISTOPERATIONERROR = 'FailedOperation.KubernetesListOperationError'
+
 # An unknown error occurs while calling the underlying CLB.
 FAILEDOPERATION_LBCOMMON = 'FailedOperation.LbCommon'
 
@@ -101,7 +104,7 @@ FAILEDOPERATION_OSNOTSUPPORT = 'FailedOperation.OsNotSupport'
 # Invalid parameter.
 FAILEDOPERATION_PARAM = 'FailedOperation.Param'
 
-# 
+# GPE error.
 FAILEDOPERATION_POLICYSERVERCOMMONERROR = 'FailedOperation.PolicyServerCommonError'
 
 # Reached the quota limit.
@@ -254,6 +257,9 @@ INTERNALERROR_KUBERNETESGETOPERATIONERROR = 'InternalError.KubernetesGetOperatio
 # Unknown Kubernetes error
 INTERNALERROR_KUBERNETESINTERNAL = 'InternalError.KubernetesInternal'
 
+# Failed to obtain the kubernetes resource list.
+INTERNALERROR_KUBERNETESLISTOPERATIONERROR = 'InternalError.KubernetesListOperationError'
+
 # An error occurs while calling the underlying CLB
 INTERNALERROR_LBCOMMON = 'InternalError.LbCommon'
 
@@ -383,6 +389,12 @@ INVALIDPARAMETER_PROMINSTANCENOTFOUND = 'InvalidParameter.PromInstanceNotFound'
 # Route table is not empty.
 INVALIDPARAMETER_ROUTETABLENOTEMPTY = 'InvalidParameter.RouteTableNotEmpty'
 
+# Invalid subnet.
+INVALIDPARAMETER_SUBNETINVALIDERROR = 'InvalidParameter.SubnetInvalidError'
+
+# The subnet does not exist.
+INVALIDPARAMETER_SUBNETNOTEXIST = 'InvalidParameter.SubnetNotExist'
+
 # Quota limit is exceeded.
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -398,9 +410,15 @@ OPERATIONDENIED_CLUSTERINDELETIONPROTECTION = 'OperationDenied.ClusterInDeletion
 # The resource is occupied.
 RESOURCEINUSE = 'ResourceInUse'
 
+# A running Pod exists.
+RESOURCEINUSE_EXISTRUNNINGPOD = 'ResourceInUse.ExistRunningPod'
+
 # The resource already exists.
 RESOURCEINUSE_RESOURCEEXISTALREADY = 'ResourceInUse.ResourceExistAlready'
 
+# The subnet already exists.
+RESOURCEINUSE_SUBNETALREADYEXIST = 'ResourceInUse.SubnetAlreadyExist'
+
 # Insufficient CVM resources.
 RESOURCEINSUFFICIENT_SPECIFIEDINSTANCETYPE = 'ResourceInsufficient.SpecifiedInstanceType'
 
@@ -428,6 +446,9 @@ RESOURCEUNAVAILABLE_CLUSTERINABNORMALSTAT = 'ResourceUnavailable.ClusterInAbnorm
 # The cluster’s status does support this operation.
 RESOURCEUNAVAILABLE_CLUSTERSTATE = 'ResourceUnavailable.ClusterState'
 
+# The node pool is in an abnormal status.
+RESOURCEUNAVAILABLE_NODEPOOLSTATENOTNORMAL = 'ResourceUnavailable.NodePoolStateNotNormal'
+
 # Unauthorized operation.
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
@@ -448,3 +469,6 @@ UNSUPPORTEDOPERATION_CLUSTERNOTSUITENABLEVPCCNI = 'UnsupportedOperation.ClusterN
 
 # The user is not in the allowlist.
 UNSUPPORTEDOPERATION_NOTINWHITELIST = 'UnsupportedOperation.NotInWhitelist'
+
+# Virtual nodes cannot be installed.
+UNSUPPORTEDOPERATION_NOTSUPPORTINSTALLVIRTUALKUBELET = 'UnsupportedOperation.NotSupportInstallVirtualKubelet'
